Mendeley Python SDK
===================

.. image:: https://pypip.in/d/mendeley/badge.png
  :target: https://pypi.python.org/pypi/mendeley/
.. image:: https://pypip.in/v/mendeley/badge.png
  :target: https://pypi.python.org/pypi/mendeley/
.. image:: https://pypip.in/format/mendeley/badge.png
  :target: https://pypi.python.org/pypi/mendeley/
.. image:: https://pypip.in/license/mendeley/badge.png
  :target: https://pypi.python.org/pypi/mendeley/
.. image:: https://readthedocs.org/projects/mendeley-python/badge/?version=latest
  :target: https://readthedocs.org/projects/mendeley-python/?badge=latest

The Mendeley Python SDK provides access to the `Mendeley <http://www.mendeley.com>`_ API.  For more information on the
API and its capabilities, see the `developer portal <http://dev.mendeley.com>`_.

Installation
------------

Install from `PyPI <https://pypi.python.org/pypi>`_ using `pip <http://www.pip-installer.org/en/latest/>`_, a
package manager for Python.

.. code-block:: bash

    pip install mendeley

Documentation
-------------

Full documentation, including examples, can be found on `ReadTheDocs <http://mendeley-python.readthedocs.org/>`_.

Compatibility
-------------

The SDK has been tested with Python 2.7 and 3.4.

Sample applications
-------------------

There are two sample applications that illustrate how to use the SDK:

- `mendeley-api-python-example <https://github.com/Mendeley/mendeley-api-python-example>`_, a
  `Flask <http://flask.pocoo.org/>`_ web application for accessing a user's library.
- `mendeley-api-python-catalog-example <https://github.com/Mendeley/mendeley-api-python-catalog-example>`_, a
  command-line application for accessing the Mendeley catalog.

